@@ -21,11 +21,8 @@
 #include "emoticontexteditselector.h"
 #include "emoticonunicodetab.h"
 #include "textutils.h"
-#include <KEmoticons>
 #include <kemoticonstheme.h>
 
-#include <QListWidget>
-#include <QPixmap>
 #include <QHBoxLayout>
 
 using namespace KPIMTextEdit;
@@ -60,13 +57,3 @@ void EmoticonTextEditSelector::loadEmoticons()
         mUnicodeTab->loadEmoticons();
     }
 }
-
-bool EmoticonTextEditSelector::emojiPlainText() const
-{
-    return mUnicodeTab->emojiPlainText();
-}
-
-void EmoticonTextEditSelector::setEmojiPlainText(bool emojiPlainText)
-{
-    mUnicodeTab->setEmojiPlainText(emojiPlainText);
-}
