@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,9 +23,10 @@
 #include "kpimtextedit_export.h"
 #include <QWidget>
 #include <QTextDocument>
-
-namespace KPIMTextEdit
-{
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+#include <QRegularExpression>
+#endif
+namespace KPIMTextEdit {
 class TextFindWidget;
 class TextReplaceWidget;
 class KPIMTEXTEDIT_EXPORT TextEditFindBarBase : public QWidget
@@ -33,10 +34,10 @@ class KPIMTEXTEDIT_EXPORT TextEditFindBarBase : public QWidget
     Q_OBJECT
 
 public:
-    explicit TextEditFindBarBase(QWidget *parent = Q_NULLPTR);
-    ~TextEditFindBarBase();
+    explicit TextEditFindBarBase(QWidget *parent = nullptr);
+    ~TextEditFindBarBase() override;
 
-    QString text() const;
+    Q_REQUIRED_RESULT QString text() const;
     void setText(const QString &text);
 
     void focusAndSetCursor();
@@ -53,9 +54,14 @@ protected:
     virtual bool viewIsReadOnly() const = 0;
     virtual bool documentIsEmpty() const = 0;
     virtual bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) = 0;
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+    virtual bool searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions) = 0;
+#else
+    virtual bool searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions) = 0;
+#endif
     virtual void autoSearchMoveCursor() = 0;
 
-    bool event(QEvent *e) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
     void clearSelections();
     void updateHighLight(bool);
     bool searchText(bool backward, bool isAutoSearch);
@@ -79,11 +85,15 @@ private Q_SLOTS:
 
 protected:
     QString mLastSearchStr;
-    TextFindWidget *mFindWidget;
-    TextReplaceWidget *mReplaceWidget;
-    bool mHideWhenClose;
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+    QRegExp mLastSearchRegExp;
+#else
+    QRegularExpression mLastSearchRegExp;
+#endif
+    TextFindWidget *mFindWidget = nullptr;
+    TextReplaceWidget *mReplaceWidget = nullptr;
+    bool mHideWhenClose = true;
 };
-
 }
 
 #endif // TEXTEDITFINDBARBASE_H
