@@ -689,9 +689,9 @@ void PlainTextEditor::moveLineUpDown(bool moveUp)
 void PlainTextEditor::wheelEvent(QWheelEvent *event)
 {
     if (QApplication::keyboardModifiers() & Qt::ControlModifier) {
-        if (event->delta() > 0) {
+        if (event->angleDelta().y() > 0) {
             zoomIn();
-        } else if (event->delta() < 0) {
+        } else if (event->angleDelta().y() < 0) {
             zoomOut();
         }
         event->accept();
